@@ -4,6 +4,9 @@
 #' @param ... additional arguments to be passed to or from methods.
 #' @export
 as.data.frame.labelled <- function(x, ...) {
-  if (typeof(x) == "character")
-    as.data.frame.character(x, stringsAsFactors = FALSE) else as.data.frame.numeric(x)
+  if (typeof(x) == "character") {
+    as.data.frame.character(x, stringsAsFactors = FALSE)
+  } else {
+    as.data.frame.numeric(x)
+  }
 }
