@@ -80,6 +80,46 @@ sort_val_labels(v, decreasing = TRUE)
 ## ------------------------------------------------------------------------
 sort_val_labels(v, according_to = "l")
 
+## ------------------------------------------------------------------------
+v <- labelled(c(1,2,2,2,3,9,1,3,2,NA), c(yes = 1, no = 3, "don't know" = 9))
+v
+na_values(v) <- 9
+na_values(v)
+v
+na_values(v) <- NULL
+v
+na_range(v) <- c(5, Inf)
+na_range(v)
+v
+
+## ---- eval=FALSE---------------------------------------------------------
+#  x <- c(1, 2, 2, 9)
+#  na_values(x) <- 9
+
+## ------------------------------------------------------------------------
+x <- c(1, 2, 2, 9)
+val_labels(x) <- c(yes = 1, no = 2)
+na_values(x) <- 9
+x
+
+## ------------------------------------------------------------------------
+v <- labelled_spss(1:10, c(Good = 1, Bad = 8), na_values = c(9, 10))
+v
+v2 <- user_na_to_na(v)
+v2
+
+## ------------------------------------------------------------------------
+v <- labelled_spss(1:10, c(Good = 1, Bad = 8), na_values = c(9, 10))
+v
+v2 <- remove_user_na(v)
+v2
+
+## ------------------------------------------------------------------------
+v <- labelled_spss(1:10, c(Good = 1, Bad = 8), na_values = c(9, 10))
+v
+na_values(v) <- NULL
+v
+
 ## ------------------------------------------------------------------------
 v <- labelled(c(1,2,2,2,3,9,1,3,2,NA), c(yes = 1, maybe = 2, no = 3))
 v
